@@ -64,6 +64,37 @@ def get_fulfillment_orders(client, order_number):
     return client.get(uri).json()['fulfillment_orders']
 
 
+def get_fulfillments(client, order_number):
+    uri = f'{client.api_path}/orders/{order_number}/fulfillments.json'
+    return client.get(uri).json()['fulfillments']
+
+
+def create_tracking_options(fulfillment_id, tracking_number, 
+                            company=None, message=None, url=None, 
+                            notify=False):
+    return {
+        "fulfillment": {
+            "message": message,
+            "notify_customer": notify,
+            "tracking_info": {
+                "number": tracking_number,
+                "company": company,
+                "url": url
+                },
+            "line_items_by_fulfillment_order": [
+                {
+                    "fulfillment_order_id": fulfillment_id
+                }
+            ]
+        }
+    }
+
+
+def create_fulfillment_with_tracking(client, options):
+    uri = f'{client.api_path}/fulfillments.json'
+    return client.post(uri, json=options).json()
+
+
 def _generate_refund_line_items(fulfillments, restock_type):
     return [
         {
